==> fullcalendar-vue-5.13.3.tgz: package/src/FullCalendar.ts <==
import { Calendar } from '@fullcalendar/core';
import { OPTION_IS_COMPLEX } from './options'
import { shallowCopy, mapHash } from './utils'
import { wrapVDomGenerator, createVueContentTypePlugin } from './custom-content-type'
import { defineComponent, getCurrentInstance, onBeforeUnmount, onBeforeUpdate, onMounted, ref, useSlots, watch } from 'vue';

export default defineComponent({
  name: 'FullCalendar',
  props: {
    options: {
      type: Object,
      default: () => ({})
    }
  },
  render(h) {
    return h('div', {
      attrs: {
        'data-fc-render-id': this.renderId
      }
    })
  },
  setup(props) {
    const renderId = ref(0);

    const instance = getCurrentInstance();

    const root = instance && instance.proxy;

    if (!root) { return {}; }

    function buildOptions(suppliedOptions: any) {
      let internal = root && root.$options as any
      suppliedOptions = suppliedOptions || {}
      return {
        ...internal.scopedSlotOptions,
        ...suppliedOptions, // spread will pull out the values from the options getter functions
        plugins: (suppliedOptions.plugins || []).concat([
          createVueContentTypePlugin(root as any)
        ])
      }
    }

    function getApi(): Calendar {
      return (root && root.$options as any).calendar;
    }

    onMounted(() => {
      let internal = root.$options as any
      internal.scopedSlotOptions = mapHash(root.$scopedSlots, wrapVDomGenerator) // needed for buildOptions

      const calendar = new Calendar((root as any).$el, buildOptions(props.options))
      internal.calendar = calendar
      calendar.render();
    })

    onBeforeUpdate(() => getApi().resumeRendering());
    onBeforeUnmount(() => getApi().destroy());

    watch(() => props.options, val => {
      let calendar = getApi()
      calendar.pauseRendering()
      calendar.resetOptions(buildOptions(val))
      renderId.value++ // will queue a rerender
    }, { deep: true })

    for (const complexOptionName in OPTION_IS_COMPLEX) {
      watch(() => props.options[complexOptionName], val => {
        // unfortunately the handler is called with undefined if new props were set, but the complex one wasn't ever set
        if (val !== undefined) {

          let calendar = getApi()
          calendar.pauseRendering()
          calendar.resetOptions({
            [complexOptionName]: shallowCopy(val)
          }, true)

          renderId.value++
        }
      })
    }

    return {
      getApi,
      renderId
    }
  }
});

==> fullcalendar-vue-5.13.4.tgz: package/src/FullCalendar.ts <==
import { Calendar } from '@fullcalendar/core';
import { OPTION_IS_COMPLEX } from './options'
import { shallowCopy, mapHash } from './utils'
import { wrapVDomGenerator, createVueContentTypePlugin } from './custom-content-type'
import { defineComponent, getCurrentInstance, onBeforeUnmount, onBeforeUpdate, onMounted, ref, watch, h } from 'vue';

export default defineComponent({
  name: 'FullCalendar',
  props: {
    options: {
      type: Object,
      default: () => ({})
    }
  },
  setup(props, { expose }) {
    const renderId = ref(0);

    const instance = getCurrentInstance();

    const root = instance && instance.proxy;

    if (!root) { return {}; }

    function buildOptions(suppliedOptions: any) {
      let internal = root && root.$options as any
      suppliedOptions = suppliedOptions || {}
      return {
        ...internal.scopedSlotOptions,
        ...suppliedOptions, // spread will pull out the values from the options getter functions
        plugins: (suppliedOptions.plugins || []).concat([
          createVueContentTypePlugin(root as any)
        ])
      }
    }

    function getApi(): Calendar {
      return (root && root.$options as any).calendar;
    }

    onMounted(() => {
      let internal = root.$options as any
      internal.scopedSlotOptions = mapHash(root.$scopedSlots, wrapVDomGenerator) // needed for buildOptions

      const calendar = new Calendar((root as any).$el, buildOptions(props.options))
      internal.calendar = calendar
      calendar.render();
    })

    onBeforeUpdate(() => getApi().resumeRendering());
    onBeforeUnmount(() => getApi().destroy());

    watch(() => props.options, val => {
      let calendar = getApi()
      calendar.pauseRendering()
      calendar.resetOptions(buildOptions(val))
      renderId.value++ // will queue a rerender
    }, { deep: true })

    for (const complexOptionName in OPTION_IS_COMPLEX) {
      watch(() => props.options[complexOptionName], val => {
        // unfortunately the handler is called with undefined if new props were set, but the complex one wasn't ever set
        if (val !== undefined) {

          let calendar = getApi()
          calendar.pauseRendering()
          calendar.resetOptions({
            [complexOptionName]: shallowCopy(val)
          }, true)

          renderId.value++
        }
      })
    }

    expose({
      getApi,
      renderId
    })

    return () => h('div', {
      attrs: {
        'data-fc-render-id': renderId.value
      }
    })
  }
});
